==> apache-hyracks-0.3.2-source-release.zip: apache-hyracks-0.3.2/hyracks/hyracks-control/hyracks-control-nc/src/main/java/org/apache/hyracks/control/nc/task/ThreadDumpTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.hyracks.control.nc.task;

import java.util.logging.Level;
import java.util.logging.Logger;

import org.apache.hyracks.control.common.utils.ThreadDumpHelper;
import org.apache.hyracks.control.nc.NodeControllerService;

public class ThreadDumpTask implements Runnable {
    private static final Logger LOGGER = Logger.getLogger(ThreadDumpTask.class.getName());
    private final NodeControllerService ncs;
    private final String requestId;

    public ThreadDumpTask(NodeControllerService ncs, String requestId) {
        this.ncs = ncs;
        this.requestId = requestId;
    }

    @Override
    public void run() {
        String result;
        try {
            result = ThreadDumpHelper.takeDumpJSON(ncs.getThreadMXBean());
        } catch (Exception e) {
            LOGGER.log(Level.WARNING, "Exception taking thread dump", e);
            result = null;
        }
        try {
            ncs.getClusterController().notifyThreadDump(
                    ncs.getContext().getNodeId(), requestId, result);
        } catch (Exception e) {
            LOGGER.log(Level.WARNING, "Exception sending thread dump to CC", e);
        }
    }
}

==> apache-hyracks-0.3.3-source-release.zip: apache-hyracks-0.3.3/hyracks/hyracks-control/hyracks-control-nc/src/main/java/org/apache/hyracks/control/nc/task/ThreadDumpTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.hyracks.control.nc.task;

import java.util.logging.Level;
import java.util.logging.Logger;

import org.apache.hyracks.util.ThreadDumpUtil;
import org.apache.hyracks.control.nc.NodeControllerService;

public class ThreadDumpTask implements Runnable {
    private static final Logger LOGGER = Logger.getLogger(ThreadDumpTask.class.getName());
    private final NodeControllerService ncs;
    private final String requestId;

    public ThreadDumpTask(NodeControllerService ncs, String requestId) {
        this.ncs = ncs;
        this.requestId = requestId;
    }

    @Override
    public void run() {
        String result;
        try {
            result = ThreadDumpUtil.takeDumpJSONString();
        } catch (Exception e) {
            LOGGER.log(Level.WARNING, "Exception taking thread dump", e);
            result = null;
        }
        try {
            ncs.getClusterController().notifyThreadDump(
                    ncs.getContext().getNodeId(), requestId, result);
        } catch (Exception e) {
            LOGGER.log(Level.WARNING, "Exception sending thread dump to CC", e);
        }
    }
}
